@@ -22,7 +22,7 @@ class ManageFiles():
                 file_extention = r.headers['x-ext'].replace('.','')
                 file_location = os.path.join(base_path,f"{file_key}.{file_extention}")
                 total_length = int(r.headers.get("Content-Length"))
-                with tqdm.wrapattr(r.raw, "read", total=total_length, desc="")as raw:
+                with tqdm.wrapattr(r.raw, "read", total=total_length, desc=f"Downloading {file_key}")as raw:
                     with open(file_location, 'wb')as output:
                         shutil.copyfileobj(raw, output)
             return 'File Downloaded Successfully', file_key, r.headers, True
